@@ -34,6 +34,14 @@ class Feishu:
         self._access_token = None
 
     def send(self, text):
+        """
+        description:
+            发送文本消息到飞书群
+        parameters:
+            text(str): 要发送的文本内容
+        return:
+            success(bool): 发送是否成功
+        """
         print(text)
         headers = {"Content-Type": "application/json"}
         data = {"msg_type": "text", "content": {"text": text}}
@@ -47,6 +55,14 @@ class Feishu:
         )
 
     async def send_async(self, text: str):
+        """
+        description:
+            异步发送文本消息到飞书群
+        parameters:
+            text(str): 要发送的文本内容
+        return:
+            success(bool): 发送是否成功
+        """
         return await asyncio.to_thread(self.send, text)
 
     def send_markdown(
@@ -55,6 +71,16 @@ class Feishu:
         title: str,
         template: str = "turquoise",
     ):
+        """
+        description:
+            发送Markdown格式的消息到飞书群
+        parameters:
+            markdown_content(str): Markdown格式的内容
+            title(str): 消息标题
+            template(str): 卡片模板颜色，默认为"turquoise"
+        return:
+            success(bool): 发送是否成功
+        """
         headers = {"Content-Type": "application/json; charset=utf-8"}
         card = {
             "config": {"wide_screen_mode": True, "enable_forward": True},
@@ -78,6 +104,16 @@ class Feishu:
         title: str,
         template: str = "turquoise",
     ):
+        """
+        description:
+            异步发送Markdown格式的消息到飞书群
+        parameters:
+            markdown_content(str): Markdown格式的内容
+            title(str): 消息标题
+            template(str): 卡片模板颜色，默认为"turquoise"
+        return:
+            success(bool): 发送是否成功
+        """
         return await asyncio.to_thread(
             self.send_markdown, markdown_content, title, template
         )
@@ -89,6 +125,17 @@ class Feishu:
         title: str,
         template: str = "turquoise",
     ):
+        """
+        description:
+            发送表格消息到飞书群
+        parameters:
+            headers(list): 表头列表
+            rows(list): 表格行数据列表
+            title(str): 消息标题
+            template(str): 卡片模板颜色，默认为"turquoise"
+        return:
+            success(bool): 发送是否成功
+        """
         headers_req = {"Content-Type": "application/json; charset=utf-8"}
         n_cols = len(headers)
         columns = []
@@ -144,6 +191,17 @@ class Feishu:
         title: str,
         template: str = "turquoise",
     ):
+        """
+        description:
+            异步发送表格消息到飞书群
+        parameters:
+            headers(list[str]): 表头列表
+            rows(list[list[str]]): 表格行数据列表
+            title(str): 消息标题
+            template(str): 卡片模板颜色，默认为"turquoise"
+        return:
+            success(bool): 发送是否成功
+        """
         return await asyncio.to_thread(self.send_table, headers, rows, title, template)
 
     def send_file(
@@ -196,4 +254,14 @@ class Feishu:
             return False
 
     async def send_file_async(self, file_url: str, title: str, template: str):
+        """
+        description:
+            异步发送文件到飞书群
+        parameters:
+            file_url(str): 文件下载链接
+            title(str): 消息标题
+            template(str): 卡片模板颜色
+        return:
+            success(bool): 发送是否成功
+        """
         return await asyncio.to_thread(self.send_file, file_url, title, template)
